# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.demand_forecast_api import DemandForecastApi  # noqa: E501
from elexonpy.rest import ApiException


class TestDemandForecastApi(unittest.TestCase):
    """DemandForecastApi unit test stubs"""

    def setUp(self):
        self.api = DemandForecastApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_forecast_demand_daily_evolution_get(self):
        """Test case for forecast_demand_daily_evolution_get

        Evolution of the fourteen-day demand forecast over time (NDFD, TSDFD)  # noqa: E501
        """
        pass

    def test_forecast_demand_daily_get(self):
        """Test case for forecast_demand_daily_get

        Fourteen day demand forecast (NDFD, TSDFD)  # noqa: E501
        """
        pass

    def test_forecast_demand_daily_history_get(self):
        """Test case for forecast_demand_daily_history_get

        History of the fourteen-day demand forecast (NDFD, TSDFD)  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_earliest_get(self):
        """Test case for forecast_demand_day_ahead_earliest_get

        Historic view of the earliest forecasted demand (NDF, TSDF)  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_earliest_stream_get(self):
        """Test case for forecast_demand_day_ahead_earliest_stream_get

        Historic view of the earliest forecasted demand (NDF, TSDF) stream  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_evolution_get(self):
        """Test case for forecast_demand_day_ahead_evolution_get

        Evolution of the day-ahead demand forecast over time (NDF, TSDF)  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_get(self):
        """Test case for forecast_demand_day_ahead_get

        Day-ahead demand forecast (NDF, TSDF)  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_history_get(self):
        """Test case for forecast_demand_day_ahead_history_get

        History of the day-ahead demand forecast (NDF, TSDF)  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_latest_get(self):
        """Test case for forecast_demand_day_ahead_latest_get

        Historic view of the latest forecasted demand (NDF, TSDF)  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_latest_stream_get(self):
        """Test case for forecast_demand_day_ahead_latest_stream_get

        Historic view of the latest forecasted demand (NDF, TSDF) stream  # noqa: E501
        """
        pass

    def test_forecast_demand_day_ahead_peak_get(self):
        """Test case for forecast_demand_day_ahead_peak_get

        Peak forecasted demand per day (TSDF)  # noqa: E501
        """
        pass

    def test_forecast_demand_total_day_ahead_get(self):
        """Test case for forecast_demand_total_day_ahead_get

        Day-ahead total load forecast (DATL/B0620)  # noqa: E501
        """
        pass

    def test_forecast_demand_total_week_ahead_get(self):
        """Test case for forecast_demand_total_week_ahead_get

        Week-ahead total load forecast (WATL/B0630)  # noqa: E501
        """
        pass

    def test_forecast_demand_total_week_ahead_latest_get(self):
        """Test case for forecast_demand_total_week_ahead_latest_get

        Latest week-ahead total load forecast (WATL/B0630)  # noqa: E501
        """
        pass

    def test_forecast_demand_weekly_evolution_get(self):
        """Test case for forecast_demand_weekly_evolution_get

        Evolution of the one-year demand forecast over time  (NDFW, TSDFW)  # noqa: E501
        """
        pass

    def test_forecast_demand_weekly_get(self):
        """Test case for forecast_demand_weekly_get

        One-year demand forecast (NDFW, TSDFW)  # noqa: E501
        """
        pass

    def test_forecast_demand_weekly_history_get(self):
        """Test case for forecast_demand_weekly_history_get

        History of the one-year demand forecast (NDFW, TSDFW)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class MarketIndexApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def balancing_pricing_market_index_get(self, _from, to, **kwargs):  # noqa: E501
        """Market Index Data (MID) price time series  # noqa: E501

        This endpoint provides Market Index Data received from NGESO.                Market Index Data is a key component in the calculation of System Buy Price and System Sell Price for each  Settlement Period. This data is received from each of the appointed Market Index Data Providers (MIDPs) and  reflects the price of wholesale electricity in Great Britain in the short term markets. The Market Index Data  which is received from each MIDP for each Settlement Period consists of a Market Index Volume and  Market Index Price, representing the volume and price of trading for the relevant period in the market operated  by the MIDP. The Market Price (the volume weighed average Market Index Price) is used to derive  the Reverse Price (SBP or SSP).\"                The two data providers available to query are N2EX (\"N2EXMIDP\") and APX (\"APXMIDP\").    By default, the from and to parameters filter the data by time inclusively. If the settlementPeriodFrom or  settlementPeriodTo parameters are provided, the corresponding from or to parameter instead filters on settlement  date, allowing for searching by a combination of time and/or settlement date & settlement period.  Note: When filtering via settlement date, from/to are treated as Dates only, with the time being ignored. For  example, 2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering from start time to start time:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z                Filtering from start time to settlement date and period:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodTo=1                Filtering from settlement date and period to start time:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1                Filtering from settlement date and period to settlement date and period:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1&settlementPeriodTo=1  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_pricing_market_index_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: The \"from\" start time or settlement date for the filter. (required)
        :param datetime to: The \"to\" start time or settlement date for the filter. (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param list[str] data_providers: The data providers to query. If no data provider is selected both will be displayed.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingMarketIndexResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_pricing_market_index_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_pricing_market_index_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def balancing_pricing_market_index_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """Market Index Data (MID) price time series  # noqa: E501

        This endpoint provides Market Index Data received from NGESO.                Market Index Data is a key component in the calculation of System Buy Price and System Sell Price for each  Settlement Period. This data is received from each of the appointed Market Index Data Providers (MIDPs) and  reflects the price of wholesale electricity in Great Britain in the short term markets. The Market Index Data  which is received from each MIDP for each Settlement Period consists of a Market Index Volume and  Market Index Price, representing the volume and price of trading for the relevant period in the market operated  by the MIDP. The Market Price (the volume weighed average Market Index Price) is used to derive  the Reverse Price (SBP or SSP).\"                The two data providers available to query are N2EX (\"N2EXMIDP\") and APX (\"APXMIDP\").    By default, the from and to parameters filter the data by time inclusively. If the settlementPeriodFrom or  settlementPeriodTo parameters are provided, the corresponding from or to parameter instead filters on settlement  date, allowing for searching by a combination of time and/or settlement date & settlement period.  Note: When filtering via settlement date, from/to are treated as Dates only, with the time being ignored. For  example, 2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering from start time to start time:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z                Filtering from start time to settlement date and period:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodTo=1                Filtering from settlement date and period to start time:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1                Filtering from settlement date and period to settlement date and period:                    /balancing/pricing/market-index?from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1&settlementPeriodTo=1  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_pricing_market_index_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: The \"from\" start time or settlement date for the filter. (required)
        :param datetime to: The \"to\" start time or settlement date for the filter. (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param list[str] data_providers: The data providers to query. If no data provider is selected both will be displayed.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingMarketIndexResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'settlement_period_from', 'settlement_period_to', 'data_providers', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_pricing_market_index_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `balancing_pricing_market_index_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `balancing_pricing_market_index_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'data_providers' in params:
            query_params.append(('dataProviders', params['data_providers']))  # noqa: E501
            collection_formats['dataProviders'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/pricing/market-index', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingMarketIndexResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.datasets_api import DatasetsApi  # noqa: E501
from elexonpy.rest import ApiException


class TestDatasetsApi(unittest.TestCase):
    """DatasetsApi unit test stubs"""

    def setUp(self):
        self.api = DatasetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_datasets_abuc_get(self):
        """Test case for datasets_abuc_get

        Amount Of Balancing Reserves Under Contract (ABUC / B1720)  # noqa: E501
        """
        pass

    def test_datasets_abuc_stream_get(self):
        """Test case for datasets_abuc_stream_get

        Amount Of Balancing Reserves Under Contract (ABUC / B1720) stream  # noqa: E501
        """
        pass

    def test_datasets_agpt_get(self):
        """Test case for datasets_agpt_get

        Actual Aggregated Generation Per Type (AGPT / B1620)  # noqa: E501
        """
        pass

    def test_datasets_agpt_stream_get(self):
        """Test case for datasets_agpt_stream_get

        Actual Aggregated Generation Per Type (AGPT / B1620) stream  # noqa: E501
        """
        pass

    def test_datasets_agws_get(self):
        """Test case for datasets_agws_get

        Actual Or Estimated Wind And Solar Power Generation (AGWS / B1630)  # noqa: E501
        """
        pass

    def test_datasets_agws_stream_get(self):
        """Test case for datasets_agws_stream_get

        Actual Or Estimated Wind And Solar Power Generation (AGWS / B1630) stream  # noqa: E501
        """
        pass

    def test_datasets_aobe_get(self):
        """Test case for datasets_aobe_get

        Accepted Offered Balancing Energy (AOBE)  # noqa: E501
        """
        pass

    def test_datasets_aobe_stream_get(self):
        """Test case for datasets_aobe_stream_get

        Accepted Offered Balancing Energy (AOBE) stream  # noqa: E501
        """
        pass

    def test_datasets_atl_get(self):
        """Test case for datasets_atl_get

        Actual Total Load Per Bidding Zone (ATL / B0610)  # noqa: E501
        """
        pass

    def test_datasets_atl_stream_get(self):
        """Test case for datasets_atl_stream_get

        Actual Total Load Per Bidding Zone (ATL / B0610) stream  # noqa: E501
        """
        pass

    def test_datasets_b1610_get(self):
        """Test case for datasets_b1610_get

        Actual Generation Output Per Generation Unit (B1610)  # noqa: E501
        """
        pass

    def test_datasets_b1610_stream_get(self):
        """Test case for datasets_b1610_stream_get

        Actual Generation Output Per Generation Unit (B1610) stream  # noqa: E501
        """
        pass

    def test_datasets_beb_get(self):
        """Test case for datasets_beb_get

        Balancing Energy Bids (BEB)  # noqa: E501
        """
        pass

    def test_datasets_beb_stream_get(self):
        """Test case for datasets_beb_stream_get

        Balancing Energy Bids (BEB) stream  # noqa: E501
        """
        pass

    def test_datasets_boalf_get(self):
        """Test case for datasets_boalf_get

        Bid Offer Acceptance Level Flagged (BOALF)  # noqa: E501
        """
        pass

    def test_datasets_boalf_stream_get(self):
        """Test case for datasets_boalf_stream_get

        Bid Offer Acceptance Level Flagged (BOALF) stream  # noqa: E501
        """
        pass

    def test_datasets_bod_get(self):
        """Test case for datasets_bod_get

        Bid Offer Data (BOD)  # noqa: E501
        """
        pass

    def test_datasets_bod_stream_get(self):
        """Test case for datasets_bod_stream_get

        Bid-Offer Data (BOD) stream  # noqa: E501
        """
        pass

    def test_datasets_cbs_get(self):
        """Test case for datasets_cbs_get

        Current Balancing State (CBS)  # noqa: E501
        """
        pass

    def test_datasets_cbs_stream_get(self):
        """Test case for datasets_cbs_stream_get

        Current Balancing State (CBS) stream  # noqa: E501
        """
        pass

    def test_datasets_ccm_get(self):
        """Test case for datasets_ccm_get

        Cost of Congestion Management (CCM / B1330)  # noqa: E501
        """
        pass

    def test_datasets_ccm_stream_get(self):
        """Test case for datasets_ccm_stream_get

        Cost of Congestion Management (CCM / B1330) stream  # noqa: E501
        """
        pass

    def test_datasets_cdn_get(self):
        """Test case for datasets_cdn_get

        Credit default notices (CDN)  # noqa: E501
        """
        pass

    def test_datasets_cdn_stream_get(self):
        """Test case for datasets_cdn_stream_get

        Credit default notices (CDN)  # noqa: E501
        """
        pass

    def test_datasets_dag_get(self):
        """Test case for datasets_dag_get

        Day-Ahead Aggregated Generation (DAG / B1430)  # noqa: E501
        """
        pass

    def test_datasets_dag_stream_get(self):
        """Test case for datasets_dag_stream_get

        Day-Ahead Aggregated Generation (DAG / B1430) stream  # noqa: E501
        """
        pass

    def test_datasets_datl_get(self):
        """Test case for datasets_datl_get

        Day-Ahead Total Load Forecast Per Bidding Zone (DATL / B0620)  # noqa: E501
        """
        pass

    def test_datasets_datl_stream_get(self):
        """Test case for datasets_datl_stream_get

        Day-Ahead Total Load Forecast Per Bidding Zone (DATL / B0620) stream  # noqa: E501
        """
        pass

    def test_datasets_dci_get(self):
        """Test case for datasets_dci_get

        Demand control instructions (DCI)  # noqa: E501
        """
        pass

    def test_datasets_dci_stream_get(self):
        """Test case for datasets_dci_stream_get

        Demand control instructions (DCI) stream  # noqa: E501
        """
        pass

    def test_datasets_dgws_get(self):
        """Test case for datasets_dgws_get

        Day-Ahead Generation For Wind And Solar (DGWS / B1440)  # noqa: E501
        """
        pass

    def test_datasets_dgws_stream_get(self):
        """Test case for datasets_dgws_stream_get

        Day-Ahead Generation For Wind And Solar (DGWS / B1440) stream  # noqa: E501
        """
        pass

    def test_datasets_disbsad_get(self):
        """Test case for datasets_disbsad_get

        Disaggregated Balancing Services Adjustment Data (DISBSAD)  # noqa: E501
        """
        pass

    def test_datasets_disbsad_stream_get(self):
        """Test case for datasets_disbsad_stream_get

        Disaggregated Balancing Services Adjustment Data (DISBSAD) stream  # noqa: E501
        """
        pass

    def test_datasets_feib_get(self):
        """Test case for datasets_feib_get

        Financial Expenses and Income for Balancing (FEIB / B1790)  # noqa: E501
        """
        pass

    def test_datasets_feib_stream_get(self):
        """Test case for datasets_feib_stream_get

        Financial Expenses and Income for Balancing (FEIB / B1790) stream  # noqa: E501
        """
        pass

    def test_datasets_fou2_t14_d_get(self):
        """Test case for datasets_fou2_t14_d_get

        2 to 14 days ahead generation availability aggregated by fuel type (FOU2T14D)  # noqa: E501
        """
        pass

    def test_datasets_fou2_t3_yw_get(self):
        """Test case for datasets_fou2_t3_yw_get

        2 to 156 weeks ahead generation availability aggregated by fuel type (FOU2T3YW)  # noqa: E501
        """
        pass

    def test_datasets_freq_get(self):
        """Test case for datasets_freq_get

        System frequency (FREQ)  # noqa: E501
        """
        pass

    def test_datasets_freq_stream_get(self):
        """Test case for datasets_freq_stream_get

        System frequency (FREQ) stream  # noqa: E501
        """
        pass

    def test_datasets_fuelhh_get(self):
        """Test case for datasets_fuelhh_get

        Half-hourly generation outturn by fuel type (FUELHH)  # noqa: E501
        """
        pass

    def test_datasets_fuelhh_stream_get(self):
        """Test case for datasets_fuelhh_stream_get

        Half-hourly generation outturn by fuel type (FUELHH) stream  # noqa: E501
        """
        pass

    def test_datasets_fuelinst_get(self):
        """Test case for datasets_fuelinst_get

        Instantaneous generation outturn by fuel type (FUELINST)  # noqa: E501
        """
        pass

    def test_datasets_fuelinst_stream_get(self):
        """Test case for datasets_fuelinst_stream_get

        Instantaneous generation outturn by fuel type (FUELINST) stream  # noqa: E501
        """
        pass

    def test_datasets_igca_get(self):
        """Test case for datasets_igca_get

        Installed Generation Capacity Aggregated (IGCA / B1410)  # noqa: E501
        """
        pass

    def test_datasets_igca_stream_get(self):
        """Test case for datasets_igca_stream_get

        Installed Generation Capacity Aggregated (IGCA / B1410) stream  # noqa: E501
        """
        pass

    def test_datasets_igcpu_get(self):
        """Test case for datasets_igcpu_get

        Installed Generation Capacity per Unit (IGCPU / B1420)  # noqa: E501
        """
        pass

    def test_datasets_igcpu_stream_get(self):
        """Test case for datasets_igcpu_stream_get

        Installed Generation Capacity per Unit (IGCPU / B1420) stream  # noqa: E501
        """
        pass

    def test_datasets_imbalngc_get(self):
        """Test case for datasets_imbalngc_get

        Day and day-ahead indicated imbalance (IMBALNGC)  # noqa: E501
        """
        pass

    def test_datasets_imbalngc_stream_get(self):
        """Test case for datasets_imbalngc_stream_get

        Day and day-ahead indicated imbalance (IMBALNGC) stream  # noqa: E501
        """
        pass

    def test_datasets_inddem_get(self):
        """Test case for datasets_inddem_get

        Day and day-ahead indicated demand (INDDEM)  # noqa: E501
        """
        pass

    def test_datasets_inddem_stream_get(self):
        """Test case for datasets_inddem_stream_get

        Day and day-ahead indicated demand (INDDEM) stream  # noqa: E501
        """
        pass

    def test_datasets_indgen_get(self):
        """Test case for datasets_indgen_get

        Day and day-ahead indicated generation (INDGEN)  # noqa: E501
        """
        pass

    def test_datasets_indgen_stream_get(self):
        """Test case for datasets_indgen_stream_get

        Day and day-ahead indicated generation (INDGEN) stream  # noqa: E501
        """
        pass

    def test_datasets_indo_get(self):
        """Test case for datasets_indo_get

        Initial National Demand outturn (INDO)  # noqa: E501
        """
        pass

    def test_datasets_indod_get(self):
        """Test case for datasets_indod_get

        Initial National Demand outturn daily (INDOD)  # noqa: E501
        """
        pass

    def test_datasets_indod_stream_get(self):
        """Test case for datasets_indod_stream_get

        Initial National Demand outturn daily (INDOD) stream  # noqa: E501
        """
        pass

    def test_datasets_itsdo_get(self):
        """Test case for datasets_itsdo_get

        Initial Transmission System Demand outturn (ITSDO)  # noqa: E501
        """
        pass

    def test_datasets_lolpdrm_get(self):
        """Test case for datasets_lolpdrm_get

        Loss of load probability and de-rated margin (LOLPDRM)  # noqa: E501
        """
        pass

    def test_datasets_lolpdrm_stream_get(self):
        """Test case for datasets_lolpdrm_stream_get

        Loss of load probability and de-rated margin (LOLPDRM)  # noqa: E501
        """
        pass

    def test_datasets_matl_get(self):
        """Test case for datasets_matl_get

        Month-Ahead Total Load Forecast Per Bidding Zone (MATL / B0640)  # noqa: E501
        """
        pass

    def test_datasets_matl_stream_get(self):
        """Test case for datasets_matl_stream_get

        Month-Ahead Total Load Forecast Per Bidding Zone (MATL / B0640) stream  # noqa: E501
        """
        pass

    def test_datasets_mdp_get(self):
        """Test case for datasets_mdp_get

        Maximum Delivery Period (MDP)  # noqa: E501
        """
        pass

    def test_datasets_mdp_stream_get(self):
        """Test case for datasets_mdp_stream_get

        Maximum Delivery Period (MDP) stream  # noqa: E501
        """
        pass

    def test_datasets_mdv_get(self):
        """Test case for datasets_mdv_get

        Maximum Delivery Volume (MDV)  # noqa: E501
        """
        pass

    def test_datasets_mdv_stream_get(self):
        """Test case for datasets_mdv_stream_get

        Maximum Delivery Volume (MDV) stream  # noqa: E501
        """
        pass

    def test_datasets_melngc_get(self):
        """Test case for datasets_melngc_get

        Day and day-ahead indicated margin (MELNGC)  # noqa: E501
        """
        pass

    def test_datasets_melngc_stream_get(self):
        """Test case for datasets_melngc_stream_get

        Day and day-ahead indicated margin (MELNGC) stream  # noqa: E501
        """
        pass

    def test_datasets_mels_get(self):
        """Test case for datasets_mels_get

        Maximum Export Limit (MELS)  # noqa: E501
        """
        pass

    def test_datasets_mels_stream_get(self):
        """Test case for datasets_mels_stream_get

        Maximum Export Limit (MELS) stream  # noqa: E501
        """
        pass

    def test_datasets_metadata_latest_get(self):
        """Test case for datasets_metadata_latest_get

        Returns the time when each dataset was last updated  # noqa: E501
        """
        pass

    def test_datasets_mid_get(self):
        """Test case for datasets_mid_get

        Market Index Data (MID)  # noqa: E501
        """
        pass

    def test_datasets_mid_stream_get(self):
        """Test case for datasets_mid_stream_get

        Market Index Data (MID) stream  # noqa: E501
        """
        pass

    def test_datasets_mils_get(self):
        """Test case for datasets_mils_get

        Maximum Import Limit (MILS)  # noqa: E501
        """
        pass

    def test_datasets_mils_stream_get(self):
        """Test case for datasets_mils_stream_get

        Maximum Import Limit (MILS) stream  # noqa: E501
        """
        pass

    def test_datasets_mnzt_get(self):
        """Test case for datasets_mnzt_get

        Minimum Non-Zero Time (MNZT)  # noqa: E501
        """
        pass

    def test_datasets_mnzt_stream_get(self):
        """Test case for datasets_mnzt_stream_get

        Minimum Non-Zero Time (MNZT) stream  # noqa: E501
        """
        pass

    def test_datasets_mzt_get(self):
        """Test case for datasets_mzt_get

        Minimum Zero Time (MZT)  # noqa: E501
        """
        pass

    def test_datasets_mzt_stream_get(self):
        """Test case for datasets_mzt_stream_get

        Minimum Zero Time (MZT) stream  # noqa: E501
        """
        pass

    def test_datasets_ndf_get(self):
        """Test case for datasets_ndf_get

        Day and day-ahead National Demand forecast (NDF)  # noqa: E501
        """
        pass

    def test_datasets_ndf_stream_get(self):
        """Test case for datasets_ndf_stream_get

        Day and day-ahead National Demand forecast (NDF) stream  # noqa: E501
        """
        pass

    def test_datasets_ndfd_get(self):
        """Test case for datasets_ndfd_get

        2-14 days ahead National Demand and surplus forecast (NDFD)  # noqa: E501
        """
        pass

    def test_datasets_ndfd_stream_get(self):
        """Test case for datasets_ndfd_stream_get

        2-14 days ahead National Demand and surplus forecast (NDFD) stream  # noqa: E501
        """
        pass

    def test_datasets_ndfw_get(self):
        """Test case for datasets_ndfw_get

        2-52 weeks ahead National Demand and surplus forecast (NDFW)  # noqa: E501
        """
        pass

    def test_datasets_ndfw_stream_get(self):
        """Test case for datasets_ndfw_stream_get

        2-52 weeks ahead National Demand and surplus forecast (NDFW) stream  # noqa: E501
        """
        pass

    def test_datasets_ndz_get(self):
        """Test case for datasets_ndz_get

        Notice to Deviate from Zero (NDZ)  # noqa: E501
        """
        pass

    def test_datasets_ndz_stream_get(self):
        """Test case for datasets_ndz_stream_get

        Notice to Deviate from Zero (NDZ) stream  # noqa: E501
        """
        pass

    def test_datasets_netbsad_get(self):
        """Test case for datasets_netbsad_get

        Net Balancing Services Adjustment Data (NETBSAD)  # noqa: E501
        """
        pass

    def test_datasets_netbsad_stream_get(self):
        """Test case for datasets_netbsad_stream_get

        Net Balancing Services Adjustment Data (NETBSAD)  # noqa: E501
        """
        pass

    def test_datasets_nonbm_get(self):
        """Test case for datasets_nonbm_get

        Non-BM STOR (NONBM)  # noqa: E501
        """
        pass

    def test_datasets_nonbm_stream_get(self):
        """Test case for datasets_nonbm_stream_get

        Non-BM STOR (NONBM) stream  # noqa: E501
        """
        pass

    def test_datasets_nou2_t14_d_get(self):
        """Test case for datasets_nou2_t14_d_get

        2 to 14 days ahead generation availability aggregated data (NOU2T14D)  # noqa: E501
        """
        pass

    def test_datasets_nou2_t3_yw_get(self):
        """Test case for datasets_nou2_t3_yw_get

        2 to 156 weeks ahead generation availability aggregated data (NOU2T3YW)  # noqa: E501
        """
        pass

    def test_datasets_ntb_get(self):
        """Test case for datasets_ntb_get

        Notice to Deliver Bids (NTB)  # noqa: E501
        """
        pass

    def test_datasets_ntb_stream_get(self):
        """Test case for datasets_ntb_stream_get

        Notice to Deliver Bids (NTB) stream  # noqa: E501
        """
        pass

    def test_datasets_nto_get(self):
        """Test case for datasets_nto_get

        Notice to Deliver Offers (NTO)  # noqa: E501
        """
        pass

    def test_datasets_nto_stream_get(self):
        """Test case for datasets_nto_stream_get

        Notice to Deliver Offers (NTO) stream  # noqa: E501
        """
        pass

    def test_datasets_ocnmf3_y2_get(self):
        """Test case for datasets_ocnmf3_y2_get

        2-156 weeks ahead demand margin forecast (OCNMF3Y2)  # noqa: E501
        """
        pass

    def test_datasets_ocnmf3_y2_stream_get(self):
        """Test case for datasets_ocnmf3_y2_stream_get

        2-156 weeks ahead demand margin forecast (OCNMF3Y2) stream  # noqa: E501
        """
        pass

    def test_datasets_ocnmf3_y_get(self):
        """Test case for datasets_ocnmf3_y_get

        2-156 weeks ahead demand surplus forecast (OCNMF3Y)  # noqa: E501
        """
        pass

    def test_datasets_ocnmf3_y_stream_get(self):
        """Test case for datasets_ocnmf3_y_stream_get

        2-156 weeks ahead demand surplus forecast (OCNMF3Y) stream  # noqa: E501
        """
        pass

    def test_datasets_ocnmfd2_get(self):
        """Test case for datasets_ocnmfd2_get

        2-14 days ahead demand margin forecast (OCNMFD2)  # noqa: E501
        """
        pass

    def test_datasets_ocnmfd2_stream_get(self):
        """Test case for datasets_ocnmfd2_stream_get

        2-14 days ahead demand margin forecast (OCNMFD2) stream  # noqa: E501
        """
        pass

    def test_datasets_ocnmfd_get(self):
        """Test case for datasets_ocnmfd_get

        2-14 days ahead demand surplus forecast (OCNMFD)  # noqa: E501
        """
        pass

    def test_datasets_ocnmfd_stream_get(self):
        """Test case for datasets_ocnmfd_stream_get

        2-14 days ahead demand surplus forecast (OCNMFD) stream  # noqa: E501
        """
        pass

    def test_datasets_pbc_get(self):
        """Test case for datasets_pbc_get

        Procured Balancing Capacity (PBC)  # noqa: E501
        """
        pass

    def test_datasets_pbc_stream_get(self):
        """Test case for datasets_pbc_stream_get

        Procured Balancing Capacity (PBC) stream  # noqa: E501
        """
        pass

    def test_datasets_pn_get(self):
        """Test case for datasets_pn_get

        Physical Notifications (PN)  # noqa: E501
        """
        pass

    def test_datasets_pn_stream_get(self):
        """Test case for datasets_pn_stream_get

        Physical Notifications (PN) stream  # noqa: E501
        """
        pass

    def test_datasets_ppbr_get(self):
        """Test case for datasets_ppbr_get

        Prices Of Procured Balancing Reserves (PPBR / B1730)  # noqa: E501
        """
        pass

    def test_datasets_ppbr_stream_get(self):
        """Test case for datasets_ppbr_stream_get

        Prices Of Procured Balancing Reserves (PPBR / B1730) stream  # noqa: E501
        """
        pass

    def test_datasets_qas_get(self):
        """Test case for datasets_qas_get

        Balancing Services Volume (QAS)  # noqa: E501
        """
        pass

    def test_datasets_qas_stream_get(self):
        """Test case for datasets_qas_stream_get

        Balancing Services Volume (QAS) stream  # noqa: E501
        """
        pass

    def test_datasets_qpn_get(self):
        """Test case for datasets_qpn_get

        Quiescent Physical Notifications (QPN)  # noqa: E501
        """
        pass

    def test_datasets_qpn_stream_get(self):
        """Test case for datasets_qpn_stream_get

        Quiescent Physical Notifications (QPN) stream  # noqa: E501
        """
        pass

    def test_datasets_rdre_get(self):
        """Test case for datasets_rdre_get

        Run Down Rate Export (RDRE)  # noqa: E501
        """
        pass

    def test_datasets_rdre_stream_get(self):
        """Test case for datasets_rdre_stream_get

        Run Down Rate Export (RDRE) stream  # noqa: E501
        """
        pass

    def test_datasets_rdri_get(self):
        """Test case for datasets_rdri_get

        Run Down Rate Import (RDRI)  # noqa: E501
        """
        pass

    def test_datasets_rdri_stream_get(self):
        """Test case for datasets_rdri_stream_get

        Run Down Rate Import (RDRI) stream  # noqa: E501
        """
        pass

    def test_datasets_remit_get(self):
        """Test case for datasets_remit_get

        The Regulation on Wholesale Energy Markets Integrity and Transparency (REMIT)  # noqa: E501
        """
        pass

    def test_datasets_remit_stream_get(self):
        """Test case for datasets_remit_stream_get

        The Regulation on Wholesale Energy Markets Integrity and Transparency (REMIT) stream  # noqa: E501
        """
        pass

    def test_datasets_rure_get(self):
        """Test case for datasets_rure_get

        Run Up Rate Export (RURE)  # noqa: E501
        """
        pass

    def test_datasets_rure_stream_get(self):
        """Test case for datasets_rure_stream_get

        Run Up Rate Export (RURE) stream  # noqa: E501
        """
        pass

    def test_datasets_ruri_get(self):
        """Test case for datasets_ruri_get

        Run Up Rate Import (RURI)  # noqa: E501
        """
        pass

    def test_datasets_ruri_stream_get(self):
        """Test case for datasets_ruri_stream_get

        Run Up Rate Import (RURI) stream  # noqa: E501
        """
        pass

    def test_datasets_sel_get(self):
        """Test case for datasets_sel_get

        Stable Export Limit (SEL)  # noqa: E501
        """
        pass

    def test_datasets_sel_stream_get(self):
        """Test case for datasets_sel_stream_get

        Stable Export Limit (SEL) stream  # noqa: E501
        """
        pass

    def test_datasets_sil_get(self):
        """Test case for datasets_sil_get

        Stable Import Limit (SIL)  # noqa: E501
        """
        pass

    def test_datasets_sil_stream_get(self):
        """Test case for datasets_sil_stream_get

        Stable Import Limit (SIL) stream  # noqa: E501
        """
        pass

    def test_datasets_soso_get(self):
        """Test case for datasets_soso_get

        SO-SO prices (SOSO)  # noqa: E501
        """
        pass

    def test_datasets_soso_stream_get(self):
        """Test case for datasets_soso_stream_get

        SO-SO prices (SOSO) stream  # noqa: E501
        """
        pass

    def test_datasets_syswarn_get(self):
        """Test case for datasets_syswarn_get

        System warnings (SYSWARN)  # noqa: E501
        """
        pass

    def test_datasets_syswarn_stream_get(self):
        """Test case for datasets_syswarn_stream_get

        System warnings (SYSWARN) stream  # noqa: E501
        """
        pass

    def test_datasets_temp_get(self):
        """Test case for datasets_temp_get

        Temperature data (TEMP)  # noqa: E501
        """
        pass

    def test_datasets_tsdf_get(self):
        """Test case for datasets_tsdf_get

        Day and day-ahead Transmission System Demand forecast (TSDF)  # noqa: E501
        """
        pass

    def test_datasets_tsdf_stream_get(self):
        """Test case for datasets_tsdf_stream_get

        Day and day-ahead Transmission System Demand forecast (TSDF) stream  # noqa: E501
        """
        pass

    def test_datasets_tsdfd_get(self):
        """Test case for datasets_tsdfd_get

        2-14 days ahead Transmission System Demand and surplus forecast (TSDFD)  # noqa: E501
        """
        pass

    def test_datasets_tsdfd_stream_get(self):
        """Test case for datasets_tsdfd_stream_get

        2-14 days ahead Transmission System Demand and surplus forecast (TSDFD) stream  # noqa: E501
        """
        pass

    def test_datasets_tsdfw_get(self):
        """Test case for datasets_tsdfw_get

        2-52 weeks ahead Transmission System Demand and surplus forecast (TSDFW)  # noqa: E501
        """
        pass

    def test_datasets_tsdfw_stream_get(self):
        """Test case for datasets_tsdfw_stream_get

        2-52 weeks ahead Transmission System Demand and surplus forecast (TSDFW) stream  # noqa: E501
        """
        pass

    def test_datasets_tudm_get(self):
        """Test case for datasets_tudm_get

        Trading unit data (S0491_TUDM)  # noqa: E501
        """
        pass

    def test_datasets_tudm_stream_get(self):
        """Test case for datasets_tudm_stream_get

        Trading unit data (S0491_TUDM) stream  # noqa: E501
        """
        pass

    def test_datasets_uou2_t14_d_get(self):
        """Test case for datasets_uou2_t14_d_get

        2 to 14 days ahead generation availability aggregated by Balancing Mechanism Units (UOU2T14D)  # noqa: E501
        """
        pass

    def test_datasets_uou2_t14_d_stream_get(self):
        """Test case for datasets_uou2_t14_d_stream_get

        2 to 14 days ahead generation availability aggregated by Balancing Mechanism Units (UOU2T14D) stream  # noqa: E501
        """
        pass

    def test_datasets_uou2_t3_yw_get(self):
        """Test case for datasets_uou2_t3_yw_get

        2 to 156 weeks ahead generation availability aggregated by Balancing Mechanism Units (UOU2T3YW)  # noqa: E501
        """
        pass

    def test_datasets_uou2_t3_yw_stream_get(self):
        """Test case for datasets_uou2_t3_yw_stream_get

        2 to 156 weeks ahead generation availability aggregated by Balancing Mechanism Units (UOU2T3YW) stream  # noqa: E501
        """
        pass

    def test_datasets_watl_get(self):
        """Test case for datasets_watl_get

        Week-Ahead Total Load Forecast Per Bidding Zone (WATL / B0630)  # noqa: E501
        """
        pass

    def test_datasets_watl_stream_get(self):
        """Test case for datasets_watl_stream_get

        Week-Ahead Total Load Forecast Per Bidding Zone (WATL / B0630) stream  # noqa: E501
        """
        pass

    def test_datasets_windfor_get(self):
        """Test case for datasets_windfor_get

        Wind generation forecast (WINDFOR)  # noqa: E501
        """
        pass

    def test_datasets_windfor_stream_get(self):
        """Test case for datasets_windfor_stream_get

        Wind generation forecast (WINDFOR) stream  # noqa: E501
        """
        pass

    def test_datasets_yafm_get(self):
        """Test case for datasets_yafm_get

        Year Ahead Forecast Margin (YAFM / B0810)  # noqa: E501
        """
        pass

    def test_datasets_yafm_stream_get(self):
        """Test case for datasets_yafm_stream_get

        Year Ahead Forecast Margin (YAFM / B0810) stream  # noqa: E501
        """
        pass

    def test_datasets_yatl_get(self):
        """Test case for datasets_yatl_get

        Year-Ahead Total Load Forecast Per Bidding Zone (YATL / B0650)  # noqa: E501
        """
        pass

    def test_datasets_yatl_stream_get(self):
        """Test case for datasets_yatl_stream_get

        Year-Ahead Total Load Forecast Per Bidding Zone (YATL / B0650) stream  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class REMITApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def remit_get(self, message_id, **kwargs):  # noqa: E501
        """Bulk fetch message details by IDs  # noqa: E501

        This endpoint provides one or more REMIT messages based on the given message IDs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_get(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[int] message_id: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_get_with_http_info(message_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_get_with_http_info(message_id, **kwargs)  # noqa: E501
            return data

    def remit_get_with_http_info(self, message_id, **kwargs):  # noqa: E501
        """Bulk fetch message details by IDs  # noqa: E501

        This endpoint provides one or more REMIT messages based on the given message IDs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_get_with_http_info(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[int] message_id: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'message_id' is set
        if ('message_id' not in params or
                params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `remit_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'message_id' in params:
            query_params.append(('messageId', params['message_id']))  # noqa: E501
            collection_formats['messageId'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_list_by_event_get(self, _from, to, **kwargs):  # noqa: E501
        """List messages by event time  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the event start time, end time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_event_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_list_by_event_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_list_by_event_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def remit_list_by_event_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """List messages by event time  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the event start time, end time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_event_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'participant_id', 'asset_id', 'message_type', 'unavailability_type', 'event_type', 'fuel_type', 'latest_revision_only', 'profile_only', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_list_by_event_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `remit_list_by_event_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `remit_list_by_event_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'participant_id' in params:
            query_params.append(('participantId', params['participant_id']))  # noqa: E501
        if 'asset_id' in params:
            query_params.append(('assetId', params['asset_id']))  # noqa: E501
        if 'message_type' in params:
            query_params.append(('messageType', params['message_type']))  # noqa: E501
        if 'unavailability_type' in params:
            query_params.append(('unavailabilityType', params['unavailability_type']))  # noqa: E501
        if 'event_type' in params:
            query_params.append(('eventType', params['event_type']))  # noqa: E501
            collection_formats['eventType'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'latest_revision_only' in params:
            query_params.append(('latestRevisionOnly', params['latest_revision_only']))  # noqa: E501
        if 'profile_only' in params:
            query_params.append(('profileOnly', params['profile_only']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/list/by-event', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_list_by_event_stream_get(self, _from, to, **kwargs):  # noqa: E501
        """List messages by event time (stream)  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the event start, end time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.                This endpoint has an optimised JSON payload and is aimed at frequent requests for this data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_event_stream_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :return: list[InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_list_by_event_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_list_by_event_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def remit_list_by_event_stream_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """List messages by event time (stream)  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the event start, end time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.                This endpoint has an optimised JSON payload and is aimed at frequent requests for this data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_event_stream_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :return: list[InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'participant_id', 'asset_id', 'message_type', 'unavailability_type', 'event_type', 'fuel_type', 'latest_revision_only', 'profile_only']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_list_by_event_stream_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `remit_list_by_event_stream_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `remit_list_by_event_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'participant_id' in params:
            query_params.append(('participantId', params['participant_id']))  # noqa: E501
        if 'asset_id' in params:
            query_params.append(('assetId', params['asset_id']))  # noqa: E501
        if 'message_type' in params:
            query_params.append(('messageType', params['message_type']))  # noqa: E501
        if 'unavailability_type' in params:
            query_params.append(('unavailabilityType', params['unavailability_type']))  # noqa: E501
        if 'event_type' in params:
            query_params.append(('eventType', params['event_type']))  # noqa: E501
            collection_formats['eventType'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'latest_revision_only' in params:
            query_params.append(('latestRevisionOnly', params['latest_revision_only']))  # noqa: E501
        if 'profile_only' in params:
            query_params.append(('profileOnly', params['profile_only']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/list/by-event/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_list_by_publish_get(self, _from, to, **kwargs):  # noqa: E501
        """List messages by publish time  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the publish time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_publish_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_list_by_publish_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_list_by_publish_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def remit_list_by_publish_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """List messages by publish time  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the publish time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_publish_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'participant_id', 'asset_id', 'message_type', 'unavailability_type', 'event_type', 'fuel_type', 'latest_revision_only', 'profile_only', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_list_by_publish_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `remit_list_by_publish_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `remit_list_by_publish_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'participant_id' in params:
            query_params.append(('participantId', params['participant_id']))  # noqa: E501
        if 'asset_id' in params:
            query_params.append(('assetId', params['asset_id']))  # noqa: E501
        if 'message_type' in params:
            query_params.append(('messageType', params['message_type']))  # noqa: E501
        if 'unavailability_type' in params:
            query_params.append(('unavailabilityType', params['unavailability_type']))  # noqa: E501
        if 'event_type' in params:
            query_params.append(('eventType', params['event_type']))  # noqa: E501
            collection_formats['eventType'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'latest_revision_only' in params:
            query_params.append(('latestRevisionOnly', params['latest_revision_only']))  # noqa: E501
        if 'profile_only' in params:
            query_params.append(('profileOnly', params['profile_only']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/list/by-publish', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_list_by_publish_stream_get(self, _from, to, **kwargs):  # noqa: E501
        """List messages by publish time (stream)  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the publish time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.                This endpoint has an optimised JSON payload and is aimed at frequent requests for this data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_publish_stream_get(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :return: list[InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_list_by_publish_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_list_by_publish_stream_get_with_http_info(_from, to, **kwargs)  # noqa: E501
            return data

    def remit_list_by_publish_stream_get_with_http_info(self, _from, to, **kwargs):  # noqa: E501
        """List messages by publish time (stream)  # noqa: E501

        This endpoint provides a list of REMIT message identifiers based on the publish time and other optional parameters.                - Filtering by LatestRevisionOnly (default = true):     if true, include only the latest revision of each message.                - Filtering by ProfileOnly (default = false):      if true, include only messages with an outage profile.                This endpoint has an optimised JSON payload and is aimed at frequent requests for this data.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_list_by_publish_stream_get_with_http_info(_from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime _from: (required)
        :param datetime to: (required)
        :param str participant_id:
        :param str asset_id:
        :param str message_type:
        :param str unavailability_type:
        :param list[str] event_type:
        :param list[str] fuel_type:
        :param bool latest_revision_only:
        :param bool profile_only:
        :return: list[InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['_from', 'to', 'participant_id', 'asset_id', 'message_type', 'unavailability_type', 'event_type', 'fuel_type', 'latest_revision_only', 'profile_only']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_list_by_publish_stream_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `remit_list_by_publish_stream_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `remit_list_by_publish_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'participant_id' in params:
            query_params.append(('participantId', params['participant_id']))  # noqa: E501
        if 'asset_id' in params:
            query_params.append(('assetId', params['asset_id']))  # noqa: E501
        if 'message_type' in params:
            query_params.append(('messageType', params['message_type']))  # noqa: E501
        if 'unavailability_type' in params:
            query_params.append(('unavailabilityType', params['unavailability_type']))  # noqa: E501
        if 'event_type' in params:
            query_params.append(('eventType', params['event_type']))  # noqa: E501
            collection_formats['eventType'] = 'multi'  # noqa: E501
        if 'fuel_type' in params:
            query_params.append(('fuelType', params['fuel_type']))  # noqa: E501
            collection_formats['fuelType'] = 'multi'  # noqa: E501
        if 'latest_revision_only' in params:
            query_params.append(('latestRevisionOnly', params['latest_revision_only']))  # noqa: E501
        if 'profile_only' in params:
            query_params.append(('profileOnly', params['profile_only']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/list/by-publish/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_message_id_get(self, message_id, **kwargs):  # noqa: E501
        """Fetch message details by ID  # noqa: E501

        This endpoint provides a REMIT message based on a given message ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_message_id_get(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int message_id: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_message_id_get_with_http_info(message_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_message_id_get_with_http_info(message_id, **kwargs)  # noqa: E501
            return data

    def remit_message_id_get_with_http_info(self, message_id, **kwargs):  # noqa: E501
        """Fetch message details by ID  # noqa: E501

        This endpoint provides a REMIT message based on a given message ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_message_id_get_with_http_info(message_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int message_id: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['message_id', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_message_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'message_id' is set
        if ('message_id' not in params or
                params['message_id'] is None):
            raise ValueError("Missing the required parameter `message_id` when calling `remit_message_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_id' in params:
            path_params['messageId'] = params['message_id']  # noqa: E501

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/{messageId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_revisions_get(self, **kwargs):  # noqa: E501
        """List all message revisions  # noqa: E501

        This endpoint provides all revisions for a given REMIT message.  The message can be specified in two ways:  - the mRID  - the message ID of a specific revision, which will return the entire list of revisions for that message  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_revisions_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mrid:
        :param int message_id:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_revisions_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.remit_revisions_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def remit_revisions_get_with_http_info(self, **kwargs):  # noqa: E501
        """List all message revisions  # noqa: E501

        This endpoint provides all revisions for a given REMIT message.  The message can be specified in two ways:  - the mRID  - the message ID of a specific revision, which will return the entire list of revisions for that message  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_revisions_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mrid:
        :param int message_id:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mrid', 'message_id', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_revisions_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'mrid' in params:
            query_params.append(('mrid', params['mrid']))  # noqa: E501
        if 'message_id' in params:
            query_params.append(('messageId', params['message_id']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/revisions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageIdentifierWithUrl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remit_search_get(self, mrid, **kwargs):  # noqa: E501
        """Fetch message details by mRID  # noqa: E501

        This endpoint provides one or more REMIT messages based on the given mRID and revision number. If none is given  it returns the REMIT message revision with the latest revision number.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_search_get(mrid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mrid: (required)
        :param int revision_number:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remit_search_get_with_http_info(mrid, **kwargs)  # noqa: E501
        else:
            (data) = self.remit_search_get_with_http_info(mrid, **kwargs)  # noqa: E501
            return data

    def remit_search_get_with_http_info(self, mrid, **kwargs):  # noqa: E501
        """Fetch message details by mRID  # noqa: E501

        This endpoint provides one or more REMIT messages based on the given mRID and revision number. If none is given  it returns the REMIT message revision with the latest revision number.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remit_search_get_with_http_info(mrid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str mrid: (required)
        :param int revision_number:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['mrid', 'revision_number', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remit_search_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'mrid' is set
        if ('mrid' not in params or
                params['mrid'] is None):
            raise ValueError("Missing the required parameter `mrid` when calling `remit_search_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'mrid' in params:
            query_params.append(('mrid', params['mrid']))  # noqa: E501
        if 'revision_number' in params:
            query_params.append(('revisionNumber', params['revision_number']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/remit/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesTransparencyRemitRemitMessageWithId',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_loss_of_load_probability_derated_margin_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData(unittest.TestCase):
    """InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData(self):
        """Test InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_misc_dataset_rows_loss_of_load_probability_derated_margin_data.InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesMiscDatasetRowsLossOfLoadProbabilityDeratedMarginData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class BidOfferApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def balancing_bid_offer_all_get(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Market-wide bid-offer data (BOD)  # noqa: E501

        This endpoint provides market-wide bid-offer data, for all BMUs or a requested set of multiple BMUs.  It returns the data valid for a given settlement period, excluding any results where LevelFrom and LevelTo are both zero.                The settlement period to query must be specified as a date and settlement period. The date should be provided in the format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_bid_offer_all_get(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_bid_offer_all_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_bid_offer_all_get_with_http_info(settlement_date, settlement_period, **kwargs)  # noqa: E501
            return data

    def balancing_bid_offer_all_get_with_http_info(self, settlement_date, settlement_period, **kwargs):  # noqa: E501
        """Market-wide bid-offer data (BOD)  # noqa: E501

        This endpoint provides market-wide bid-offer data, for all BMUs or a requested set of multiple BMUs.  It returns the data valid for a given settlement period, excluding any results where LevelFrom and LevelTo are both zero.                The settlement period to query must be specified as a date and settlement period. The date should be provided in the format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_bid_offer_all_get_with_http_info(settlement_date, settlement_period, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date settlement_date: The settlement date to filter. (required)
        :param int settlement_period: The settlement period to filter. This should be an integer from 1-50 inclusive. (required)
        :param list[str] bm_unit: The BM Units to query. Elexon or NGC BMU IDs can be used. If omitted, results for all BM units will be returned.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['settlement_date', 'settlement_period', 'bm_unit', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_bid_offer_all_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'settlement_date' is set
        if ('settlement_date' not in params or
                params['settlement_date'] is None):
            raise ValueError("Missing the required parameter `settlement_date` when calling `balancing_bid_offer_all_get`")  # noqa: E501
        # verify the required parameter 'settlement_period' is set
        if ('settlement_period' not in params or
                params['settlement_period'] is None):
            raise ValueError("Missing the required parameter `settlement_period` when calling `balancing_bid_offer_all_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'settlement_date' in params:
            query_params.append(('settlementDate', params['settlement_date']))  # noqa: E501
        if 'settlement_period' in params:
            query_params.append(('settlementPeriod', params['settlement_period']))  # noqa: E501
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
            collection_formats['bmUnit'] = 'multi'  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/bid-offer/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def balancing_bid_offer_get(self, bm_unit, _from, to, **kwargs):  # noqa: E501
        """Bid-offer data per BMU (BOD)  # noqa: E501

        This endpoint provides the bid-offer data for a requested BMU. It returns the data valid over a given time  range, excluding any results where LevelFrom and LevelTo are both zero.                By default, the from and to parameters filter the data inclusively and this endpoint will return any data that  overlaps even at a single instant. If the settlementPeriodFrom or settlementPeriodTo parameters are provided, it  will instead filter to return any data that overlaps with the specified range of settlement periods. It is  possible to search using a combination of time and/or settlement date & settlement period. Note: When  filtering via settlement date, from/to are treated as Dates only, with the time being ignored. For example,  2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering by timeFrom and timeTo:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z                Filtering from timeFrom to settlement date and period:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodTo=1                Filtering from settlement date and period to TimeTo:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1                Filtering from settlement date and period to settlement date and period:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1&settlementPeriodTo=1  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_bid_offer_get(bm_unit, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bm_unit: The BM Unit to query. (required)
        :param datetime _from: The \"from\" start time or settlement date for the filter. (required)
        :param datetime to: The \"to\" start time or settlement date for the filter. (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.balancing_bid_offer_get_with_http_info(bm_unit, _from, to, **kwargs)  # noqa: E501
        else:
            (data) = self.balancing_bid_offer_get_with_http_info(bm_unit, _from, to, **kwargs)  # noqa: E501
            return data

    def balancing_bid_offer_get_with_http_info(self, bm_unit, _from, to, **kwargs):  # noqa: E501
        """Bid-offer data per BMU (BOD)  # noqa: E501

        This endpoint provides the bid-offer data for a requested BMU. It returns the data valid over a given time  range, excluding any results where LevelFrom and LevelTo are both zero.                By default, the from and to parameters filter the data inclusively and this endpoint will return any data that  overlaps even at a single instant. If the settlementPeriodFrom or settlementPeriodTo parameters are provided, it  will instead filter to return any data that overlaps with the specified range of settlement periods. It is  possible to search using a combination of time and/or settlement date & settlement period. Note: When  filtering via settlement date, from/to are treated as Dates only, with the time being ignored. For example,  2022-06-01T00:00Z and 2022-06-01T11:11Z are both treated as the settlement date 2022-06-01.                All Dates and DateTimes should be expressed as defined within  <a href=\"https://datatracker.ietf.org/doc/html/rfc3339#section-5.6\" target=\"_blank\">RFC 3339</a>.                Some examples of date parameter combinations are shown below.                Filtering by timeFrom and timeTo:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z                Filtering from timeFrom to settlement date and period:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodTo=1                Filtering from settlement date and period to TimeTo:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1                Filtering from settlement date and period to settlement date and period:                    /balancing/bid-offer?bmUnit=T_DRAXX-1&from=2022-06-01T00:00Z&to=2022-07-01T00:00Z&settlementPeriodFrom=1&settlementPeriodTo=1  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.balancing_bid_offer_get_with_http_info(bm_unit, _from, to, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str bm_unit: The BM Unit to query. (required)
        :param datetime _from: The \"from\" start time or settlement date for the filter. (required)
        :param datetime to: The \"to\" start time or settlement date for the filter. (required)
        :param int settlement_period_from: The \"from\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param int settlement_period_to: The \"to\" settlement period for the filter. This should be an integer from 1-50 inclusive.
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['bm_unit', '_from', 'to', 'settlement_period_from', 'settlement_period_to', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method balancing_bid_offer_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'bm_unit' is set
        if ('bm_unit' not in params or
                params['bm_unit'] is None):
            raise ValueError("Missing the required parameter `bm_unit` when calling `balancing_bid_offer_get`")  # noqa: E501
        # verify the required parameter '_from' is set
        if ('_from' not in params or
                params['_from'] is None):
            raise ValueError("Missing the required parameter `_from` when calling `balancing_bid_offer_get`")  # noqa: E501
        # verify the required parameter 'to' is set
        if ('to' not in params or
                params['to'] is None):
            raise ValueError("Missing the required parameter `to` when calling `balancing_bid_offer_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'bm_unit' in params:
            query_params.append(('bmUnit', params['bm_unit']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'settlement_period_from' in params:
            query_params.append(('settlementPeriodFrom', params['settlement_period_from']))  # noqa: E501
        if 'settlement_period_to' in params:
            query_params.append(('settlementPeriodTo', params['settlement_period_to']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/balancing/bid-offer', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesBalancingBidOfferResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from elexonpy.api_client import ApiClient


class MarginForecastApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def forecast_margin_daily_evolution_get(self, forecast_date, **kwargs):  # noqa: E501
        """Evolution daily margin forecast (OCNMFD2)  # noqa: E501

        This endpoint provides the daily evolution Generating Plant Operating Margin covering 2 days ahead to 14 days ahead in MW values.  The Daily API outputs the latest published data for daily margin forecast for D+2 to D+14.                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_daily_evolution_get(forecast_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date forecast_date: The forecast date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_margin_daily_evolution_get_with_http_info(forecast_date, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_margin_daily_evolution_get_with_http_info(forecast_date, **kwargs)  # noqa: E501
            return data

    def forecast_margin_daily_evolution_get_with_http_info(self, forecast_date, **kwargs):  # noqa: E501
        """Evolution daily margin forecast (OCNMFD2)  # noqa: E501

        This endpoint provides the daily evolution Generating Plant Operating Margin covering 2 days ahead to 14 days ahead in MW values.  The Daily API outputs the latest published data for daily margin forecast for D+2 to D+14.                Date parameter must be provided in the exact format yyyy-MM-dd.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_daily_evolution_get_with_http_info(forecast_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param date forecast_date: The forecast date for the filter. This must be in the format yyyy-MM-dd. (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['forecast_date', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_margin_daily_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'forecast_date' is set
        if ('forecast_date' not in params or
                params['forecast_date'] is None):
            raise ValueError("Missing the required parameter `forecast_date` when calling `forecast_margin_daily_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'forecast_date' in params:
            query_params.append(('forecastDate', params['forecast_date']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/margin/daily/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_margin_daily_get(self, **kwargs):  # noqa: E501
        """Daily margin forecast (OCNMFD2)  # noqa: E501

        This endpoint provides the Generating Plant Operating Margin covering 2 days ahead to 14 days ahead  in MW values. The Daily API outputs the latest published data for daily margin forecast for D+2 t D+14  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_daily_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_margin_daily_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_margin_daily_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_margin_daily_get_with_http_info(self, **kwargs):  # noqa: E501
        """Daily margin forecast (OCNMFD2)  # noqa: E501

        This endpoint provides the Generating Plant Operating Margin covering 2 days ahead to 14 days ahead  in MW values. The Daily API outputs the latest published data for daily margin forecast for D+2 t D+14  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_daily_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_margin_daily_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/margin/daily', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_margin_daily_history_get(self, publish_time, **kwargs):  # noqa: E501
        """Historical daily margin forecast (OCNMFD2)  # noqa: E501

        This endpoint provides the historic Generating Plant Operating Margin covering 2 days ahead to 14 days ahead in MW values.  The historic API outputs the latest published data for historic daily margin forecast for D+2 to D+14  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_daily_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_margin_daily_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_margin_daily_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_margin_daily_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """Historical daily margin forecast (OCNMFD2)  # noqa: E501

        This endpoint provides the historic Generating Plant Operating Margin covering 2 days ahead to 14 days ahead in MW values.  The historic API outputs the latest published data for historic daily margin forecast for D+2 to D+14  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_daily_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_margin_daily_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_margin_daily_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/margin/daily/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginDaily',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_margin_weekly_evolution_get(self, year, week, **kwargs):  # noqa: E501
        """Evolution daily margin forecast (OCNMFW2, OCNMF3Y2)  # noqa: E501

        This endpoint provides the daily evolution Generating Plant Operating Margin covering 2 days ahead to 14 days ahead in MW values.  The Daily API outputs the latest published data for daily margin forecast for D+2 t D+14  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_weekly_evolution_get(year, week, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: (required)
        :param int week: (required)
        :param str range:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_margin_weekly_evolution_get_with_http_info(year, week, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_margin_weekly_evolution_get_with_http_info(year, week, **kwargs)  # noqa: E501
            return data

    def forecast_margin_weekly_evolution_get_with_http_info(self, year, week, **kwargs):  # noqa: E501
        """Evolution daily margin forecast (OCNMFW2, OCNMF3Y2)  # noqa: E501

        This endpoint provides the daily evolution Generating Plant Operating Margin covering 2 days ahead to 14 days ahead in MW values.  The Daily API outputs the latest published data for daily margin forecast for D+2 t D+14  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_weekly_evolution_get_with_http_info(year, week, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: (required)
        :param int week: (required)
        :param str range:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'range', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_margin_weekly_evolution_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `forecast_margin_weekly_evolution_get`")  # noqa: E501
        # verify the required parameter 'week' is set
        if ('week' not in params or
                params['week'] is None):
            raise ValueError("Missing the required parameter `week` when calling `forecast_margin_weekly_evolution_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'range' in params:
            query_params.append(('range', params['range']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/margin/weekly/evolution', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_margin_weekly_get(self, **kwargs):  # noqa: E501
        """Weekly margin forecast (OCNMFW2, OCNMF3Y2)  # noqa: E501

        This endpoint provides the Generating Plant Operating Margin covering 2 weeks ahead to 156 weeks ahead in MW values.  The weekly API outputs the latest published data for weekly margin forecast for W+2 to W+156  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_weekly_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str range:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_margin_weekly_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.forecast_margin_weekly_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def forecast_margin_weekly_get_with_http_info(self, **kwargs):  # noqa: E501
        """Weekly margin forecast (OCNMFW2, OCNMF3Y2)  # noqa: E501

        This endpoint provides the Generating Plant Operating Margin covering 2 weeks ahead to 156 weeks ahead in MW values.  The weekly API outputs the latest published data for weekly margin forecast for W+2 to W+156  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_weekly_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str range:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['range', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_margin_weekly_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'range' in params:
            query_params.append(('range', params['range']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/margin/weekly', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def forecast_margin_weekly_history_get(self, publish_time, **kwargs):  # noqa: E501
        """Historical weekly margin forecast (OCNMFW2, OCNMF3Y2)  # noqa: E501

        This endpoint provides the weekly historic  Generating Plant Operating Margin.  This historic API output 2 weeks ahead to 156 weeks ahead in MW values  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_weekly_history_get(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str range:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.forecast_margin_weekly_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
        else:
            (data) = self.forecast_margin_weekly_history_get_with_http_info(publish_time, **kwargs)  # noqa: E501
            return data

    def forecast_margin_weekly_history_get_with_http_info(self, publish_time, **kwargs):  # noqa: E501
        """Historical weekly margin forecast (OCNMFW2, OCNMF3Y2)  # noqa: E501

        This endpoint provides the weekly historic  Generating Plant Operating Margin.  This historic API output 2 weeks ahead to 156 weeks ahead in MW values  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.forecast_margin_weekly_history_get_with_http_info(publish_time, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param datetime publish_time: (required)
        :param str range:
        :param str format: Response data format. Use json/xml to include metadata.
        :return: InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_time', 'range', 'format']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method forecast_margin_weekly_history_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_time' is set
        if ('publish_time' not in params or
                params['publish_time'] is None):
            raise ValueError("Missing the required parameter `publish_time` when calling `forecast_margin_weekly_history_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'publish_time' in params:
            query_params.append(('publishTime', params['publish_time']))  # noqa: E501
        if 'range' in params:
            query_params.append(('range', params['range']))  # noqa: E501
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json', 'application/xml', 'text/xml', 'text/csv'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/forecast/margin/weekly/history', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InsightsApiModelsResponsesResponseWithMetadata1InsightsApiModelsResponsesForecastMarginForecastMarginWeekly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
